@@ -6,7 +6,6 @@
 
 __all__ = [
     'Tool',  # refactor >> InputHandler
-    'run',
 ]
 
 import unittest
@@ -15,8 +14,6 @@ import re
 
 from gevent import Timeout
 
-from xnet.tools.run import run
-
 
 class ToolException(Exception):
     pass
@@ -211,6 +208,13 @@ class Tool(object):
         self.stderr = False  # if True, print output to stderr
         self._validate_implementations()
 
+    @classmethod
+    def _print_source(cls, fname):
+        if fname.endswith('.pyc'):
+            fname = fname[:-1]
+        assert fname.endswith('.py')
+        print open(fname).read()
+
     def _validate_implementations(self):
         #
         # assert __massage__ is classmethod generator
