@@ -18,6 +18,10 @@ class DummyTool(Tool):
             dict(dest='sleep', action='store_true')),
     ]
 
+    @classmethod
+    def print_source(self):
+        print open(__file__).read()
+
     def __parse__(self, line, iterator):
         item = line.strip()
         return {'item': item}
@@ -40,8 +44,8 @@ class DummyTool(Tool):
 
 
 def main():
-    import xnet.tools
-    xnet.tools.run(DummyTool)
+    import xnet.tools.run
+    xnet.tools.run.run(DummyTool)
 
 
 if __name__ == "__main__":
