@@ -33,6 +33,10 @@ class IISShortnameTool(WebgetTool):
             dict(dest='code', action='store_true')),
     ]
 
+    @classmethod
+    def print_source(self):
+        print open(__file__).read()
+
     def __init__(self, *args, **kw):
         super(IISShortnameTool, self).__init__(*args, **kw)
         self._url = None
@@ -143,8 +147,8 @@ Default format if verbose (-v):
 
 
 def main():
-    import xnet.tools
-    xnet.tools.run(IISShortnameTool)
+    import xnet.tools.run
+    xnet.tools.run.run(IISShortnameTool)
 
 
 if __name__ == "__main__":
