@@ -27,6 +27,10 @@ class ResolvTool(Tool):
             dict(dest='deep', action='store_true')),
     ]
 
+    @classmethod
+    def print_source(self):
+        print open(__file__).read()
+
     def __parse__(self, line, iterator):
         self._item = item = line.strip()
         result = {}
@@ -127,8 +131,8 @@ Default format:
 
 
 def main():
-    import xnet.tools
-    xnet.tools.run(ResolvTool)
+    import xnet.tools.run
+    xnet.tools.run.run(ResolvTool)
 
 
 if __name__ == "__main__":
