@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright(c) 2011 Krister Hedfors
+# Copyright(c) 2013 Krister Hedfors
 #
 
 
@@ -10,6 +10,7 @@ import doctest
 
 import sys
 import os
+import os.path
 import optparse
 import itertools
 import time
@@ -20,8 +21,10 @@ import gevent.pool
 import gevent.monkey
 from gevent.socket import wait_read
 
+import xnet.tools
 from xnet.debug import pdb
 
+
 gevent.monkey.patch_all(thread=False)
 
 DEVELOPMENT = 1
@@ -58,6 +61,8 @@ class XNetOptionParser(optparse.OptionParser):
                         help='run tests')
         self.add_option('', '--pdb', dest='pdb', action='store_true',
                         help='enable interactive pdb debugging on exceptions')
+        self.add_option('', '--print-source', dest='print_source', action='store_true',
+                        help='print source code of tool')
         self.add_option('-y', '--parallelism', dest='parallelism', metavar='n',
                         help='set parallelism (default 128)')
         self.add_option('-r', '--read', dest='read', metavar='path',
@@ -162,6 +167,7 @@ def _get_output_filepath(a, base):
     path = base + item
     return path
 
+
 def run(ToolImplementation, tool_reads_stdin=False):
     try:
         return _run(ToolImplementation, tool_reads_stdin)
@@ -192,6 +198,10 @@ def _run(ToolImplementation, tool_reads_stdin):
     if opt.pdb:
         xnet.debug.interactive_debugger_on_exception(True)
 
+    if opt.print_source:
+        ToolImplementation.print_source()
+        return
+
     #
     # chain input sources, handle options
     # precedence order: cmdline, -r, stdin
@@ -351,10 +361,86 @@ def output_action_result(a, opt, _outfile):
         outfile.close()
 
 
+
+__xnet_usage__ = '''
+
+    $$$ Merry Xnet! $$$
+
+The following xnet tools are available:
+ iprange   - IP range enumerator
+ resolv    - hostname resolver
+ tcpstate  - port scanner
+ netcats   - netcatish
+ webget    - web client
+ sslinfo   - SSL info harvester
+ iissn     - IIS shortname enumeration
+
+Analogous commands:
+$ xnet iprange ...
+$ iprange ...
+
+Develop your own xnet tools:
+$ existing_xnet_tool --print-source > newtool.py
+$ vim newtool.py
+$ xnet newtool.py ...
+'''
+
+
+def main():
+    args = sys.argv[:]
+
+    if len(args) < 2:
+        print __xnet_usage__
+        return
+
+    ToolImplementation = None
+
+    toolname = args[1]
+    if toolname.endswith('.py'):
+        if not os.path.exists(toolname):
+            print 'File not found:', toolname
+        folder = os.path.dirname(toolname)
+        if len(folder):
+            sys.path.insert(0, folder)
+        modulename = os.path.basename(toolname).rsplit('.', 1)[0]
+        toolmodule = __import__(modulename)
+        sys.path = sys.path[1:]
+        for name in dir(toolmodule):
+            val = getattr(toolmodule, name)
+            found = False
+            try:
+                if issubclass(val, xnet.tools.Tool):
+                    found = True
+            except TypeError:
+                pass
+            if found and not val is xnet.tools.Tool:
+                if not ToolImplementation is None:
+                    errmsg = 'Multiple Tool implementations in {0}: {1}, {2}'
+                    errmsg = errmsg.format(toolname, ToolImplementation, val)
+                    print errmsg
+                    sys.exit(1)
+                ToolImplementation = val
+         
+    if not ToolImplementation:    
+        if toolname == 'iprange':
+            from xnet.tools.iprange import IPRangeTool as ToolImplementation
+
+    if not ToolImplementation:
+        print 'Tool not found:', toolname
+        sys.exit(1)
+
+    sys.argv = sys.argv[1:]
+
+    result = run(ToolImplementation)
+    return result
+    
+
+
 if __name__ == "__main__":
-    if '--test' in sys.argv:
-        sys.argv.remove('--test')
-        doctest.testmod()
-        unittest.main()
+    main()
+    #if '--test' in sys.argv:
+    #    sys.argv.remove('--test')
+    #    doctest.testmod()
+    #    unittest.main()
     #else:
     #    main(*sys.argv)
